Documentation
¶
Overview ¶
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Index ¶
- Constants
- Variables
- func RegisterMsgServer(s grpc.ServiceRegistrar, srv MsgServer)
- type Acknowledgement
- func (*Acknowledgement) Descriptor() ([]byte, []int)deprecated
- func (x *Acknowledgement) GetError() string
- func (x *Acknowledgement) GetResponse() isAcknowledgement_Response
- func (x *Acknowledgement) GetResult() []byte
- func (*Acknowledgement) ProtoMessage()
- func (x *Acknowledgement) ProtoReflect() protoreflect.Message
- func (x *Acknowledgement) Reset()
- func (x *Acknowledgement) String() string
- type Acknowledgement_Error
- type Acknowledgement_Result
- type ExamplePacketData
- func (*ExamplePacketData) Descriptor() ([]byte, []int)deprecated
- func (x *ExamplePacketData) GetSender() string
- func (x *ExamplePacketData) GetSomeData() string
- func (*ExamplePacketData) ProtoMessage()
- func (x *ExamplePacketData) ProtoReflect() protoreflect.Message
- func (x *ExamplePacketData) Reset()
- func (x *ExamplePacketData) String() string
- type GenesisState
- type MsgClient
- type MsgSendExampleTx
- func (*MsgSendExampleTx) Descriptor() ([]byte, []int)deprecated
- func (x *MsgSendExampleTx) GetSender() string
- func (x *MsgSendExampleTx) GetSomeData() string
- func (x *MsgSendExampleTx) GetSourceChannel() string
- func (x *MsgSendExampleTx) GetSourcePort() string
- func (x *MsgSendExampleTx) GetTimeoutTimestamp() uint64
- func (*MsgSendExampleTx) ProtoMessage()
- func (x *MsgSendExampleTx) ProtoReflect() protoreflect.Message
- func (x *MsgSendExampleTx) Reset()
- func (x *MsgSendExampleTx) String() string
- type MsgSendExampleTxResponse
- func (*MsgSendExampleTxResponse) Descriptor() ([]byte, []int)deprecated
- func (x *MsgSendExampleTxResponse) GetSequence() uint64
- func (*MsgSendExampleTxResponse) ProtoMessage()
- func (x *MsgSendExampleTxResponse) ProtoReflect() protoreflect.Message
- func (x *MsgSendExampleTxResponse) Reset()
- func (x *MsgSendExampleTxResponse) String() string
- type MsgServer
- type UnimplementedMsgServer
- type UnsafeMsgServer
Constants ¶
const (
Msg_SendExampleTx_FullMethodName = "/ibcmodule.v1.Msg/SendExampleTx"
)
Variables ¶
var File_ibcmodule_v1_genesis_proto protoreflect.FileDescriptor
var File_ibcmodule_v1_query_proto protoreflect.FileDescriptor
var File_ibcmodule_v1_tx_proto protoreflect.FileDescriptor
var Msg_ServiceDesc = grpc.ServiceDesc{ ServiceName: "ibcmodule.v1.Msg", HandlerType: (*MsgServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "SendExampleTx", Handler: _Msg_SendExampleTx_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "ibcmodule/v1/tx.proto", }
Msg_ServiceDesc is the grpc.ServiceDesc for Msg service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterMsgServer ¶
func RegisterMsgServer(s grpc.ServiceRegistrar, srv MsgServer)
Types ¶
type Acknowledgement ¶
type Acknowledgement struct {
// response
//
// Types that are assignable to Response:
//
// *Acknowledgement_Result
// *Acknowledgement_Error
Response isAcknowledgement_Response `protobuf_oneof:"response"`
// contains filtered or unexported fields
}
Acknowledgement
func (*Acknowledgement) Descriptor
deprecated
func (*Acknowledgement) Descriptor() ([]byte, []int)
Deprecated: Use Acknowledgement.ProtoReflect.Descriptor instead.
func (*Acknowledgement) GetError ¶
func (x *Acknowledgement) GetError() string
func (*Acknowledgement) GetResponse ¶
func (x *Acknowledgement) GetResponse() isAcknowledgement_Response
func (*Acknowledgement) GetResult ¶
func (x *Acknowledgement) GetResult() []byte
func (*Acknowledgement) ProtoMessage ¶
func (*Acknowledgement) ProtoMessage()
func (*Acknowledgement) ProtoReflect ¶
func (x *Acknowledgement) ProtoReflect() protoreflect.Message
func (*Acknowledgement) Reset ¶
func (x *Acknowledgement) Reset()
func (*Acknowledgement) String ¶
func (x *Acknowledgement) String() string
type Acknowledgement_Error ¶
type Acknowledgement_Error struct {
Error string `protobuf:"bytes,22,opt,name=error,proto3,oneof"`
}
type Acknowledgement_Result ¶
type Acknowledgement_Result struct {
Result []byte `protobuf:"bytes,21,opt,name=result,proto3,oneof"`
}
type ExamplePacketData ¶
type ExamplePacketData struct {
Sender string `protobuf:"bytes,1,opt,name=sender,proto3" json:"sender,omitempty"`
SomeData string `protobuf:"bytes,2,opt,name=some_data,json=someData,proto3" json:"some_data,omitempty"`
// contains filtered or unexported fields
}
ExamplePacketData
func (*ExamplePacketData) Descriptor
deprecated
func (*ExamplePacketData) Descriptor() ([]byte, []int)
Deprecated: Use ExamplePacketData.ProtoReflect.Descriptor instead.
func (*ExamplePacketData) GetSender ¶
func (x *ExamplePacketData) GetSender() string
func (*ExamplePacketData) GetSomeData ¶
func (x *ExamplePacketData) GetSomeData() string
func (*ExamplePacketData) ProtoMessage ¶
func (*ExamplePacketData) ProtoMessage()
func (*ExamplePacketData) ProtoReflect ¶
func (x *ExamplePacketData) ProtoReflect() protoreflect.Message
func (*ExamplePacketData) Reset ¶
func (x *ExamplePacketData) Reset()
func (*ExamplePacketData) String ¶
func (x *ExamplePacketData) String() string
type GenesisState ¶
type GenesisState struct {
PortId string `protobuf:"bytes,1,opt,name=port_id,json=portId,proto3" json:"port_id,omitempty"`
// contains filtered or unexported fields
}
GenesisState defines the modules genesis state.
func (*GenesisState) Descriptor
deprecated
func (*GenesisState) Descriptor() ([]byte, []int)
Deprecated: Use GenesisState.ProtoReflect.Descriptor instead.
func (*GenesisState) GetPortId ¶
func (x *GenesisState) GetPortId() string
func (*GenesisState) ProtoMessage ¶
func (*GenesisState) ProtoMessage()
func (*GenesisState) ProtoReflect ¶
func (x *GenesisState) ProtoReflect() protoreflect.Message
func (*GenesisState) Reset ¶
func (x *GenesisState) Reset()
func (*GenesisState) String ¶
func (x *GenesisState) String() string
type MsgClient ¶
type MsgClient interface {
// SendExampleTx defines a rpc handler for MsgSendExampleTx.
SendExampleTx(ctx context.Context, in *MsgSendExampleTx, opts ...grpc.CallOption) (*MsgSendExampleTxResponse, error)
}
MsgClient is the client API for Msg service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewMsgClient ¶
func NewMsgClient(cc grpc.ClientConnInterface) MsgClient
type MsgSendExampleTx ¶
type MsgSendExampleTx struct {
Sender string `protobuf:"bytes,1,opt,name=sender,proto3" json:"sender,omitempty"`
SourcePort string `protobuf:"bytes,2,opt,name=source_port,json=sourcePort,proto3" json:"source_port,omitempty"`
SourceChannel string `protobuf:"bytes,3,opt,name=source_channel,json=sourceChannel,proto3" json:"source_channel,omitempty"`
TimeoutTimestamp uint64 `protobuf:"varint,4,opt,name=timeout_timestamp,json=timeoutTimestamp,proto3" json:"timeout_timestamp,omitempty"`
SomeData string `protobuf:"bytes,5,opt,name=some_data,json=someData,proto3" json:"some_data,omitempty"`
// contains filtered or unexported fields
}
MsgSendExampleTx defines the payload for Msg/SendExampleTx
func (*MsgSendExampleTx) Descriptor
deprecated
func (*MsgSendExampleTx) Descriptor() ([]byte, []int)
Deprecated: Use MsgSendExampleTx.ProtoReflect.Descriptor instead.
func (*MsgSendExampleTx) GetSender ¶
func (x *MsgSendExampleTx) GetSender() string
func (*MsgSendExampleTx) GetSomeData ¶
func (x *MsgSendExampleTx) GetSomeData() string
func (*MsgSendExampleTx) GetSourceChannel ¶
func (x *MsgSendExampleTx) GetSourceChannel() string
func (*MsgSendExampleTx) GetSourcePort ¶
func (x *MsgSendExampleTx) GetSourcePort() string
func (*MsgSendExampleTx) GetTimeoutTimestamp ¶
func (x *MsgSendExampleTx) GetTimeoutTimestamp() uint64
func (*MsgSendExampleTx) ProtoMessage ¶
func (*MsgSendExampleTx) ProtoMessage()
func (*MsgSendExampleTx) ProtoReflect ¶
func (x *MsgSendExampleTx) ProtoReflect() protoreflect.Message
func (*MsgSendExampleTx) Reset ¶
func (x *MsgSendExampleTx) Reset()
func (*MsgSendExampleTx) String ¶
func (x *MsgSendExampleTx) String() string
type MsgSendExampleTxResponse ¶
type MsgSendExampleTxResponse struct {
Sequence uint64 `protobuf:"varint,1,opt,name=sequence,proto3" json:"sequence,omitempty"`
// contains filtered or unexported fields
}
MsgSendExampleTxResponse defines the response.
func (*MsgSendExampleTxResponse) Descriptor
deprecated
func (*MsgSendExampleTxResponse) Descriptor() ([]byte, []int)
Deprecated: Use MsgSendExampleTxResponse.ProtoReflect.Descriptor instead.
func (*MsgSendExampleTxResponse) GetSequence ¶
func (x *MsgSendExampleTxResponse) GetSequence() uint64
func (*MsgSendExampleTxResponse) ProtoMessage ¶
func (*MsgSendExampleTxResponse) ProtoMessage()
func (*MsgSendExampleTxResponse) ProtoReflect ¶
func (x *MsgSendExampleTxResponse) ProtoReflect() protoreflect.Message
func (*MsgSendExampleTxResponse) Reset ¶
func (x *MsgSendExampleTxResponse) Reset()
func (*MsgSendExampleTxResponse) String ¶
func (x *MsgSendExampleTxResponse) String() string
type MsgServer ¶
type MsgServer interface {
// SendExampleTx defines a rpc handler for MsgSendExampleTx.
SendExampleTx(context.Context, *MsgSendExampleTx) (*MsgSendExampleTxResponse, error)
// contains filtered or unexported methods
}
MsgServer is the server API for Msg service. All implementations must embed UnimplementedMsgServer for forward compatibility
type UnimplementedMsgServer ¶
type UnimplementedMsgServer struct {
}
UnimplementedMsgServer must be embedded to have forward compatible implementations.
func (UnimplementedMsgServer) SendExampleTx ¶
func (UnimplementedMsgServer) SendExampleTx(context.Context, *MsgSendExampleTx) (*MsgSendExampleTxResponse, error)
type UnsafeMsgServer ¶
type UnsafeMsgServer interface {
// contains filtered or unexported methods
}
UnsafeMsgServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MsgServer will result in compilation errors.